<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif: xslShowHelp" />
    <!-- <xsl:include href="../format.xsl"/> -->
    <xsl:param name="xslResourceDirectory" select="cif:xslResourceDirectory"/>
    <!-- GDOT Alignment  Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslResourceDirectory}/engtheme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Výpis směrových významných bodů</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Výpis směrových významných bodů</h2>
                                <p lang ="en">
                                    Datum výpisu:&#xa0; <xsl:value-of select="cif:date()"/><br />
                                    Čas:&#xa0; <xsl:value-of select="cif:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Projekt: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Popis: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Název souboru: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Poslední revize: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Koeficient Vstupní grid: &#xa0;</th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Poznámka: &#xa0;</strong>Všechny jednotky tohoto výpisu jsou
                                                <xsl:if test="//@linearUnits = 'Imperial'">ve stopách,</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">v metrech,</xsl:if>
                                                pokud není specifikováno jinak.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <table class="margin" width="90%">
                                    <colgroup span="6">
                                        <col width="0%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                    </colgroup>
                                    <xsl:for-each select="HorizontalAlignment">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br />Trasa Název: &#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Trasa Popis : &#xa0;</th>
                                                <td align="left" colspan="3"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en" valign="top">Trasa Styl: &#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@style"/><br/>&#xa0;</td>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en"></th>
                                                <th class="underline" lang="en">Staničení</th>
                                                <th class="underline" lang="en">Y</th>
                                                <th class="underline" lang="en">X</th>
                                                <th class="underline" lang="en">Z</th>
                                                <th class="underline" lang="en">Sklon</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                          <xsl:for-each select="HorizontalEventPoints/*/*/EventPointList">
                                            <tr>
                                              <td align="left">
                                                <xsl:value-of select="@name"/>
                                              </td>
                                            </tr>
                                            <tr>
                                              <xsl:for-each select="HorizontalEventPoint">
                                                  <tr>
                                                      <td class="sidepad">
                                                          <xsl:choose>
                                                              <xsl:when test="@eventType = 'stationEvent'"></xsl:when>
                                                              <xsl:when test="@eventType = 'xyEvent'">Y+X</xsl:when>
                                                              <xsl:otherwise/>
                                                          </xsl:choose>
                                                      </td>
                                                      <td class="sidepad" align="right" nowrap="nowrap">
                                                          <xsl:value-of select="cif:stationFormat(number(GeometryPoint/station/@externalStation), string(GeometryPoint/station/@externalStationName))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:ordinateFormat(number(GeometryPoint/@northing))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:ordinateFormat(number(GeometryPoint/@easting))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:ordinateFormat(number(GeometryPoint/@elevation))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:gradeFormat(number(@grade))"/>
                                                      </td>
                                                  </tr>
                                                </xsl:for-each>
                                            </tr>
                                          </xsl:for-each>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Poznámky</h4>
            <p class="normal1" lang="en">
                Pro tento výpis musíte mít nějaké Významné body.
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
