<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif:xslShowHelp"/>
    <xsl:param name="xslResourceDirectory" select="cif:xslResourceDirectory"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslResourceDirectory}/engtheme.css"/>
                <title lang="en">Geometry Point Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">Geometry Point Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="cif:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="cif:time()"/>
                                </p>
                            </center>

                          <xsl:for-each select="GeometryProject">
                            <table class="margin" cellpadding="2" width="90%">
                              <tbody>
                                <tr>
                                  <th align="right" lang="en">Project:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="@name"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">Description:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="@description"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">Baseline (Active) Alignment:</th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="HorizontalAlignment/@name"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">File Name:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="@file"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">Last Revised:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                  <td align="left" style="font-size: 80%">
                                    <xsl:value-of select="../@inputGridScaleFactor" />
                                  </td>
                                  <td align="right" lang="en" style="font-size: 80%">
                                    <strong>Note:&#xa0; </strong>All units in this report are in
                                    <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                    <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                    unless specified otherwise.
                                  </td>
                                </tr>
                              </tbody>
                            </table>
                            <hr/>

                            <xsl:for-each select="GeometryPoint">
                              <table cellspacing="4" width="100%">
                                <thead style="display:table-header-group">
                                  <tr>
                                    <th class="underline" lang="en" align="left">Point</th>
                                    <th class="underline" lang="en" align="left">Feature</th>
                                    <th class="underline" lang="en" align="left">Description</th>
                                    <th class="underline" lang="en" align="left">Northing</th>
                                    <th class="underline" lang="en" align="left">Easting</th>
                                    <th class="underline" lang="en" align="left">Elevation</th>
                                  </tr>
                                </thead>
                                <tbody>
                                  <xsl:for-each select="GeometryPointProperties">
                                    <tr>
                                      <td align="left">
                                        <xsl:value-of select="@PointName"/>
                                      </td>
                                      <td align="left">
                                        <xsl:variable name="fullFeatureName" select="@FeatureName" />

                                        <xsl:variable name="items">
                                          <xsl:call-template name="splitStringToItems">
                                            <xsl:with-param name="list" select="$fullFeatureName" />
                                          </xsl:call-template>
                                        </xsl:variable>
                                        <xsl:value-of select="msxsl:node-set($items)/item[last()]"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="@PointDescription"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="cif:ordinateFormat(number(@northing))"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="cif:ordinateFormat(number(@easting))"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="cif:ordinateFormat(number(@elevation))"/>
                                      </td>
                                    </tr>
                                  </xsl:for-each>
                                </tbody>
                              </table>
                            </xsl:for-each>
                          </xsl:for-each>

                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <p class="normal1" lang="en">
            This report has no additional notes.
        </p>
    </xsl:template>
      <xsl:template name="splitStringToItems">
      <xsl:param name="list" />
      <xsl:variable name="delimiter" select="'\'">
      </xsl:variable>
      <xsl:variable name="newlist">
        <xsl:choose>
          <xsl:when test="contains($list, $delimiter)">
            <xsl:value-of select="normalize-space($list)" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="concat(normalize-space($list), $delimiter)"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:variable name="firstString" select="substring-before($newlist, $delimiter)" />
      <xsl:variable name="remainingString" select="substring-after($newlist, $delimiter)" />
      <item>
        <xsl:value-of select="$firstString" />
      </item>
      <xsl:if test="$remainingString">
        <xsl:call-template name="splitStringToItems">
          <xsl:with-param name="list" select="$remainingString" />
          <xsl:with-param name="delimiter" select="$delimiter" />
        </xsl:call-template>
      </xsl:if>
    </xsl:template>
</xsl:stylesheet>
