<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif: xslShowHelp" />
    <!-- <xsl:include href="../format.xsl"/> -->
    <xsl:param name="xslResourceDirectory" select="cif:xslResourceDirectory"/>
    <!-- GDOT Alignment  Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslResourceDirectory}/engtheme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">GDOT Alignment Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Horizontal Alignment Event Point List Report</h2>
                                <p lang ="en">
                                    Report Created:&#xa0; <xsl:value-of select="cif:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="cif:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised: &#xa0;</th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor: &#xa0;</th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note: &#xa0;</strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <table class="margin" width="90%">
                                    <colgroup span="6">
                                        <col width="0%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                        <col width="17%"/>
                                    </colgroup>
                                    <xsl:for-each select="HorizontalAlignment">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br />Alignment Name: &#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Alignment Description: &#xa0;</th>
                                                <td align="left" colspan="3"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en" valign="top">Alignment Style: &#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@style"/><br/>&#xa0;</td>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en"></th>
                                                <th class="underline" lang="en">Station</th>
                                                <th class="underline" lang="en">Northing</th>
                                                <th class="underline" lang="en">Easting</th>
                                                <th class="underline" lang="en">Elevation</th>
                                                <th class="underline" lang="en">Grade</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                          <xsl:for-each select="HorizontalEventPoints/*/*/EventPointList">
                                            <tr>
                                              <td align="left">
                                                <xsl:value-of select="@name"/>
                                              </td>
                                            </tr>
                                            <tr>
                                              <xsl:for-each select="HorizontalEventPoint">
                                                  <tr>
                                                      <td class="sidepad">
                                                          <xsl:choose>
                                                              <xsl:when test="@eventType = 'stationEvent'"></xsl:when>
                                                              <xsl:when test="@eventType = 'xyEvent'">N+E</xsl:when>
                                                              <xsl:otherwise/>
                                                          </xsl:choose>
                                                      </td>
                                                      <td class="sidepad" align="right" nowrap="nowrap">
                                                          <xsl:value-of select="cif:stationFormat(number(GeometryPoint/station/@externalStation), string(GeometryPoint/station/@externalStationName))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:ordinateFormat(number(GeometryPoint/@northing))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:ordinateFormat(number(GeometryPoint/@easting))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:ordinateFormat(number(GeometryPoint/@elevation))"/>
                                                      </td>
                                                      <td class="sidepad" align="right">
                                                          <xsl:value-of select="cif:gradeFormat(number(@grade))"/>
                                                      </td>
                                                  </tr>
                                                </xsl:for-each>
                                            </tr>
                                          </xsl:for-each>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must enable the Event Points option to get complete results from this report.
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
